==> mingw-w64-clang-aarch64-qt6-static-6.7.0-1-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6Qml/QmlPlugins/Qt6qtvkbstylespluginTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qtvkbstylesplugin" for configuration "Release"
set_property(TARGET Qt6::qtvkbstylesplugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbstylesplugin PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/libqtvkbstylesplugin.a"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbstylesplugin )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbstylesplugin "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/libqtvkbstylesplugin.a" )

# Import target "Qt6::qtvkbstylesplugin_resources_1" for configuration "Release"
set_property(TARGET Qt6::qtvkbstylesplugin_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbstylesplugin_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_resources_1/.rcc/qrc_qmake_QtQuick_VirtualKeyboard_Styles_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbstylesplugin_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbstylesplugin_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_resources_1/.rcc/qrc_qmake_QtQuick_VirtualKeyboard_Styles_init.cpp.obj" )

# Import target "Qt6::qtvkbstylesplugin_resources_2" for configuration "Release"
set_property(TARGET Qt6::qtvkbstylesplugin_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbstylesplugin_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_resources_2/.rcc/qrc_qtvkbstylesplugin_raw_qml_0_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbstylesplugin_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbstylesplugin_resources_2 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_resources_2/.rcc/qrc_qtvkbstylesplugin_raw_qml_0_init.cpp.obj" )

# Import target "Qt6::qtvkbstylesplugin_init" for configuration "Release"
set_property(TARGET Qt6::qtvkbstylesplugin_init APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbstylesplugin_init PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_init/qtvkbstylesplugin_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbstylesplugin_init )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbstylesplugin_init "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_init/qtvkbstylesplugin_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> mingw-w64-clang-aarch64-qt6-static-6.8.0-3-any.pkg.tar.zst: clangarm64/qt6-static/lib/cmake/Qt6Qml/QmlPlugins/Qt6qtvkbstylespluginTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::qtvkbstylesplugin" for configuration "Release"
set_property(TARGET Qt6::qtvkbstylesplugin APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbstylesplugin PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/libqtvkbstylesplugin.a"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbstylesplugin )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbstylesplugin "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/libqtvkbstylesplugin.a" )

# Import target "Qt6::qtvkbstylesplugin_resources_1" for configuration "Release"
set_property(TARGET Qt6::qtvkbstylesplugin_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbstylesplugin_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_VirtualKeyboard_Styles_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbstylesplugin_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbstylesplugin_resources_1 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_resources_1/.qt/rcc/qrc_qmake_QtQuick_VirtualKeyboard_Styles_init.cpp.obj" )

# Import target "Qt6::qtvkbstylesplugin_resources_2" for configuration "Release"
set_property(TARGET Qt6::qtvkbstylesplugin_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbstylesplugin_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_resources_2/.qt/rcc/qrc_qtvkbstylesplugin_raw_qml_0_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbstylesplugin_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbstylesplugin_resources_2 "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_resources_2/.qt/rcc/qrc_qtvkbstylesplugin_raw_qml_0_init.cpp.obj" )

# Import target "Qt6::qtvkbstylesplugin_init" for configuration "Release"
set_property(TARGET Qt6::qtvkbstylesplugin_init APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::qtvkbstylesplugin_init PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_init/qtvkbstylesplugin_init.cpp.obj"
  )

list(APPEND _cmake_import_check_targets Qt6::qtvkbstylesplugin_init )
list(APPEND _cmake_import_check_files_for_Qt6::qtvkbstylesplugin_init "${_IMPORT_PREFIX}/share/qt6/qml/QtQuick/VirtualKeyboard/Styles/objects-Release/qtvkbstylesplugin_init/qtvkbstylesplugin_init.cpp.obj" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
